@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# Created by ./mk_str_mod.pl on Tue Aug  7 12:44:34 WEST 2001
+# Created by ./mk_str_mod.pl on Wed Jan 28 22:21:25 PST 2009
 
 package Lingua::PT::VerbSuffixes ;
 use Exporter ;
@@ -14,7 +14,7 @@ a imp,3,r
 a ivo,3,er,ir,r,uer,uir
 a mdp,1,
 a mdp,3,
-ais cpres,5,edir,enir,entir,er,ir,r,uer,uir
+ais cpres,5,edir,enir,entir,er,estir,ir,r,uer,uir
 am cpres,6,er,ir,r,uer,uir
 am imp,6,r
 am ivo,6,er,ir,r,uer,uir
@@ -22,10 +22,17 @@ am mdp,6,
 am perf,6,
 amos cpres,4,er,ir,r,uer,uir
 amos ivo,4,er,ir,r,uer,uir
-arei fut,1,razer
 as cpres,2,er,ir,r,uer,uir
 as imp,2,r
 as mdp,2,
+ca cpres,1,der
+ca cpres,3,der
+ca ivo,3,der
+cais cpres,4,der
+cam cpres,6,der
+cam ivo,6,der
+camos ivo,4,der
+cas cpres,2,der
 ce cpres,1,ar
 ce cpres,3,ar
 ce ivo,3,ar
@@ -36,9 +43,10 @@ cem ivo,6,ar
 cemos cpres,4,ar
 cemos ivo,4,ar
 ces cpres,2,ar
+co pres,1,der
 cto pp,1,ioar
-de ivo,3,r
 de ivo,5,r
+de ivo,6,r
 deie cpres,1,ndiar
 des cfut,5,
 des pres,5,r
@@ -188,6 +196,7 @@ ia cpres,3,r
 ia imp,1,er
 ia imp,3,er
 ia ivo,2,ar
+ia ivo,3,r
 ia pres,3,ar
 iais cpres,5,r
 iam cond,6,
@@ -238,8 +247,12 @@ ides pres,2,edir
 idis pres,5,edir
 ido pp,1,er
 ido pres,1,edir
-ie ivo,3,ar
-iem ivo,6,ar
+ie cpres,1,ar
+ie cpres,3,ar
+ie ivo,3,ar,ear
+iem cpres,6,ar
+iem ivo,6,ar,ear
+ies cpres,2,ar
 iga cpres,1,eguir
 iga cpres,3,eguir
 iga ivo,3,eguir
@@ -288,7 +301,6 @@ intam ivo,6,entir
 intamos cpres,4,entir
 intamos ivo,4,entir
 intas cpres,2,entir
-inti ivo,5,entir
 into pres,1,entir
 io pres,1,ar,r
 ir cfut,1,er
@@ -361,7 +373,6 @@ isso pp,1,eter
 ista cpres,1,estir
 ista cpres,3,estir
 ista ivo,3,estir
-istais cpres,5,estir
 istam cpres,6,estir
 istam ivo,6,estir
 istamos cpres,4,estir
@@ -401,18 +412,15 @@ iveres cfut,2,ar,er
 ivermos cfut,4,ar,er
 iverm mdp,6,ar
 ivesse cimp,1,ar,er
-ivesse cimp,3,ar
+ivesse cimp,3,ar,er
 ivessem cimp,6,ar,er
 ivesses cimp,2,ar,er
 iveste perf,2,ar,er
 ivestes perf,5,ar,er
 ivramos mdp,4,ar,er
 ivreis mdp,5,ar,er
-ivsseis cimp,4,er
-ivsseis cimp,5,ar
-ivssemos cimp,3,er
-ivssemos cimp,4,ar
-ivsseis cimp,5,er
+ivsseis cimp,5,ar,er
+ivssemos cimp,4,ar,er
 iz perf,1,azer
 izemos perf,4,azer
 izer cfut,1,azer
@@ -495,20 +503,18 @@ jueava imp,1,guear
 jueava imp,3,guear
 jueavam imp,6,guear
 jueavas imp,2,guear
-juee cpres,1,guear
-juee cpres,3,guear
 jueei perf,1,guear
 jueeis cpres,5,guear
-jueem cpres,6,guear
 jueemos cpres,4,guear
 jueemos ivo,4,guear
-juees cpres,2,guear
 jueia ivo,2,guear
 jueia pres,3,guear
 jueiam pres,6,guear
 jueias pres,2,guear
-jueie ivo,3,guear
-jueiem ivo,6,guear
+jueie cpres,1,guear
+jueie cpres,3,guear
+jueiem cpres,6,guear
+jueies cpres,2,guear
 jueio pres,1,guear
 jueou perf,3,guear
 jueramos mdp,4,guear
@@ -517,6 +523,8 @@ juesseis cimp,5,guear
 juessemos cimp,4,guear
 juevamos imp,4,guear
 jueveis imp,5,guear
+juie ivo,3,guear
+juiem ivo,6,guear
 luto pp,1,ver
 m ivo,2,r
 m perf,1,r
@@ -706,21 +714,19 @@ queava imp,1,cear
 queava imp,3,cear
 queavam imp,6,cear
 queavas imp,2,cear
-quee cpres,1,cear
-quee cpres,3,cear
 queei perf,1,cear
 queeis cpres,5,cear
-queem cpres,6,cear
 queemos cpres,4,cear
 queemos ivo,4,cear
-quees cpres,2,cear
 quei perf,1,car
 queia ivo,2,cear
 queia pres,3,cear
 queiam pres,6,cear
 queias pres,2,cear
-queie ivo,3,cear
-queiem ivo,6,cear
+queie cpres,1,cear
+queie cpres,3,cear
+queiem cpres,6,cear
+queies cpres,2,cear
 queio pres,1,cear
 queis cpres,5,car
 quem cpres,6,car
@@ -735,19 +741,15 @@ quesseis cimp,5,cear
 quessemos cimp,4,cear
 quevamos imp,4,cear
 queveis imp,5,cear
-r cfut,1,ir
-r cfut,3,ir
-rdes cfut,5,ir
+quie ivo,3,cear
+quiem ivo,6,cear
 rei fut,1,zer
 reis fut,5,zer
-rem cfut,6,ir
 remos fut,4,zer
-res cfut,2,ir
 ria cond,1,zer
 ria cond,3,zer
 riam cond,6,zer
 rias cond,2,zer
-rmos cfut,4,ir
 r fut,3,zer
 rs fut,2,zer
 ro fut,6,zer
@@ -766,11 +768,11 @@ ssam ivo,6,der
 ssamos cpres,4,der
 ssamos ivo,4,der
 ssas cpres,2,der
-sse cimp,1,ir,r
-sse cimp,3,ir,r
+sse cimp,1,r
+sse cimp,3,r
 sse perf,1,zer
 sse perf,3,zer
-ssem cimp,6,ir,r
+ssem cimp,6,r
 ssemos perf,4,zer
 sser cfut,1,zer
 sser cfut,3,zer
@@ -779,7 +781,7 @@ sserdes cfut,5,zer
 sserem cfut,6,zer
 sseres cfut,2,zer
 ssermos cfut,4,zer
-sses cimp,2,ir,r
+sses cimp,2,r
 ssesse cimp,1,zer
 ssesse cimp,3,zer
 ssessem cimp,6,zer
@@ -835,10 +837,17 @@ uemos ivo,4,ar
 ues cpres,2,ar
 ula cpres,1,olir
 ula cpres,3,olir
+ula ivo,3,olir
 ulais cpres,5,olir
 ulam cpres,6,olir
+ulam ivo,6,olir
 ulamos cpres,4,olir
+ulamos ivo,4,olir
 ulas cpres,2,olir
+ule ivo,2,olir
+ule pres,3,olir
+ulem pres,6,olir
+ules pres,2,olir
 ulo pres,1,olir
 ulso pp,1,elir
 unha imp,1,or,r
@@ -893,6 +902,7 @@ ve perf,3,r
 vou pres,1,ir
 v cpres,1,ir
 v cpres,3,ir
+v ivo,3,ir
 vs cpres,2,ir
 vo cpres,6,ir
 vo ivo,6,ir
@@ -904,8 +914,8 @@ ramos mdp,4,ar
 reis mdp,5,ar
 s fut,2,
 s pres,2,ar,aver
-sseis cimp,5,air,ar
-ssemos cimp,4,air,ar
+sseis cimp,5,ar
+ssemos cimp,4,ar
 vamos imp,4,ar
 veis imp,5,ar
 o fut,6,
@@ -958,20 +968,18 @@ auteava imp,1,cautear
 auteava imp,3,cautear
 auteavam imp,6,cautear
 auteavas imp,2,cautear
-autee cpres,1,cautear
-autee cpres,3,cautear
 auteei perf,1,cautear
 auteeis cpres,5,cautear
-auteem cpres,6,cautear
 auteemos cpres,4,cautear
 auteemos ivo,4,cautear
-autees cpres,2,cautear
 auteia ivo,2,cautear
 auteia pres,3,cautear
 auteiam pres,6,cautear
 auteias pres,2,cautear
-auteie ivo,3,cautear
-auteiem ivo,6,cautear
+auteie cpres,1,cautear
+auteie cpres,3,cautear
+auteiem cpres,6,cautear
+auteies cpres,2,cautear
 auteio pres,1,cautear
 auteou perf,3,cautear
 auteramos mdp,4,cautear
@@ -980,6 +988,8 @@ autesseis cimp,5,cautear
 autessemos cimp,4,cautear
 autevamos imp,4,cautear
 auteveis imp,5,cautear
+autie ivo,3,cautear
+autiem ivo,6,cautear
 o pres,1,cer,cir,dir,vir,zer
 oa ivo,2,coar
 oa pres,3,coar
@@ -1088,8 +1098,6 @@ mos perf,4,ir
 mos pres,4,ir
 nhamos imp,4,er,ir
 nheis imp,5,er
-r cfut,1,ir
-r cfut,3,ir
 ra mdp,1,ir
 ra mdp,3,ir
 ram mdp,6,ir
@@ -1100,7 +1108,6 @@ rdes cfut,5,ir
 reis mdp,5,er,ir
 rem cfut,6,ir
 res cfut,2,ir
-rmos cfut,4,ir
 s pres,2,er
 s pres,5,ir
 sse cimp,1,ir
